@@ -20,10 +20,6 @@
 library(testthat)
 library(parallelDist)
 
-isCran <- function() {
-  !identical(Sys.getenv("NOT_CRAN"), "true")
-}
-
 # workaround for error "cannot open file 'startup.Rs': No such file or directory"
 Sys.setenv("R_TESTS" = "")
 test_check("parallelDist")
