@@ -1,6 +1,6 @@
 ## testMatrixDistances.R
 ##
-## Copyright (C)  2017, 2018  Alexander Eckert
+## Copyright (C)  2017, 2021  Alexander Eckert
 ##
 ## This file is part of parallelDist.
 ##
@@ -19,13 +19,13 @@
 
 context("Distance methods using matrix as input")
 
-mat.sample1 <- matrix(c(0,1,0,1,0,0,1,0), nrow = 2)
-mat.sample2 <- matrix(c(0,1,0,1,0,0,1,0,1,1), nrow = 2)
+mat.sample1 <- matrix(c(0, 1, 0, 1, 0, 0, 1, 0), nrow = 2)
+mat.sample2 <- matrix(c(0, 1, 0, 1, 0, 0, 1, 0, 1, 1), nrow = 2)
 mat.sample3 <- matrix(c(1:500), ncol = 5)
-mat.sample4 <- matrix(rep(0,100), ncol = 5)
+mat.sample4 <- matrix(rep(0, 100), ncol = 5)
 mat.sample5 <- matrix(c(-500:499), ncol = 5)
 mat.sample6 <- matrix(c(1:2), ncol = 1)
-mat.sample7 <- matrix(c(0.5,1,0,1,0,0,1,0.3,1,1), nrow = 2)
+mat.sample7 <- matrix(c(0.5, 1, 0, 1, 0, 0, 1, 0.3, 1, 1), nrow = 2)
 
 mat.list <- list(mat.sample1, mat.sample2, mat.sample3, mat.sample4, mat.sample5, mat.sample6, mat.sample7)
 
@@ -34,12 +34,14 @@ if (isCran()) {
 }
 
 testMatrixEquality <- function(matrix, method, ...) {
-  expect_equal(as.matrix(parDist(matrix, method = method, ...)), as.matrix(dist(matrix, method = method, ...)))
+  suppressNaNWarnings(expect_equal(as.matrix(parDist(matrix, method = method, ...)), as.matrix(dist(matrix, method = method, ...))))
 }
 
 library(proxy)
 testMatrixListEquality <- function(matlist, method, ...) {
-  invisible(sapply(matlist, function(x) { testMatrixEquality(x, method, ...) }))
+  invisible(sapply(matlist, function(x) {
+    testMatrixEquality(x, method, ...)
+  }))
 }
 
 test_that("error for invalid distance method shows up", {
@@ -104,9 +106,11 @@ test_that("kullback method produces same outputs as dist", {
 test_that("mahalanobis method produces same outputs as dist", {
   mat.mahalanobis <- cbind(1:6, 1:3)
   testMatrixEquality(mat.mahalanobis, "mahalanobis")
-  testMatrixEquality(mat.mahalanobis, "mahalanobis", cov=cov(mat.mahalanobis))
-  expect_equal(as.matrix(parDist(mat.mahalanobis, "mahalanobis", cov=solve(cov(mat.mahalanobis)), inverted=TRUE)),
-               as.matrix(dist(mat.mahalanobis, method = "mahalanobis", cov=cov(mat.mahalanobis))))
+  testMatrixEquality(mat.mahalanobis, "mahalanobis", cov = cov(mat.mahalanobis))
+  expect_equal(
+    as.matrix(parDist(mat.mahalanobis, "mahalanobis", cov = solve(cov(mat.mahalanobis)), inverted = TRUE)),
+    as.matrix(dist(mat.mahalanobis, method = "mahalanobis", cov = cov(mat.mahalanobis)))
+  )
 })
 test_that("mahalanobis method throws error for list of matrices input", {
   mat.mahalanobis <- cbind(1:6, 1:3)
@@ -124,7 +128,7 @@ test_that("maximum method produces same outputs as dist", {
 
 test_that("minkowski method produces same outputs as dist", {
   for (p_param in c(1:10)) {
-    testMatrixListEquality(mat.list, "minkowski", p=as.numeric(p_param))
+    testMatrixListEquality(mat.list, "minkowski", p = as.numeric(p_param))
   }
 })
 
@@ -242,20 +246,23 @@ test_that("cosine method produces same outputs as dist", {
 })
 
 # test for hamming distance method
-hammingR <- function(x, y){ sum(x != y)/length(x) }
+hammingR <- function(x, y) {
+  sum(x != y) / length(x)
+}
 
 testMatrixEqualityHamming <- function(matrix, ...) {
   testthat::expect_equal(
-    as.matrix(parDist(matrix, method = "hamming", ...))
-    , as.matrix(proxy::dist(matrix, method = hammingR, ...))
-    )
+    as.matrix(parDist(matrix, method = "hamming", ...)),
+    as.matrix(proxy::dist(matrix, method = hammingR, ...))
+  )
 }
 
 testMatrixListEqualityHamming <- function(matlist, ...) {
-  invisible(sapply(matlist, function(x) { testMatrixEqualityHamming(x, ...) }))
+  invisible(sapply(matlist, function(x) {
+    testMatrixEqualityHamming(x, ...)
+  }))
 }
 
 testthat::test_that("hamming method produces same outputs as dist", {
   testMatrixListEqualityHamming(mat.list)
-})
-
+})
\ No newline at end of file
